require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_certificateexport',
  dscmeta_resource_friendly_name: 'CertificateExport',
  dscmeta_resource_name: 'DSC_CertificateExport',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'CertificateDsc',
  dscmeta_module_version: '6.0.0',
  docs: 'The DSC CertificateExport resource type.
         Automatically generated from version 6.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_thumbprint: {
      type: 'Optional[String]',
      desc: 'The thumbprint of the certificate to export. Certificate selector parameter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_keyusage: {
      type: 'Optional[Array[String]]',
      desc: 'The key usage of the certificate to export must contain these values. Certificate selector parameter.',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_subject: {
      type: 'Optional[String]',
      desc: 'The subject of the certificate to export. Certificate selector parameter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_chainoption: {
      type: "Optional[Enum['BuildChain', 'buildchain', 'EndEntityCertOnly', 'endentitycertonly']]",
      desc: 'Specifies the options for building a chain when exporting a PFX certificate.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_password: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies the password used to protect an exported PFX file.',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_type: {
      type: "Optional[Enum['Cert', 'cert', 'P7B', 'p7b', 'SST', 'sst', 'PFX', 'pfx']]",
      desc: 'Specifies the type of certificate to export.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_issuer: {
      type: 'Optional[String]',
      desc: 'The issuer of the certificate to export. Certificate selector parameter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enhancedkeyusage: {
      type: 'Optional[Array[String]]',
      desc: 'The enhanced key usage of the certificate to export must contain these values. Certificate selector parameter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_dnsname: {
      type: 'Optional[Array[String]]',
      desc: 'The subject alternative name of the certificate to export must contain these values. Certificate selector parameter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_isexported: {
      type: 'Optional[Boolean]',
      desc: 'Returns true if the certificate file already exists and therefore has been exported.',

      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_protectto: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of strings for the username or group name that can access the private key of an exported PFX file without any password.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_friendlyname: {
      type: 'Optional[String]',
      desc: 'The friendly name of the certificate to export. Certificate selector parameter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'The path to the file you that will contain the exported certificate.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowexpired: {
      type: 'Optional[Boolean]',
      desc: 'Allow an expired certificate to be exported. Certificate selector parameter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_store: {
      type: 'Optional[String]',
      desc: "The Windows Certificate Store Name to search for the certificate to export from. Certificate selector parameter. Defaults to 'My'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_matchsource: {
      type: 'Optional[Boolean]',
      desc: 'Causes an existing exported certificate to be compared with the certificate identified for export and re-exported if it does not match.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
