require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_certificateimport',
  dscmeta_resource_friendly_name: 'CertificateImport',
  dscmeta_resource_name: 'DSC_CertificateImport',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'CertificateDsc',
  dscmeta_module_version: '6.0.0',
  docs: 'The DSC CertificateImport resource type.
         Automatically generated from version 6.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_thumbprint: {
      type: 'String',
      desc: "The thumbprint (unique identifier) of the certificate you're importing.",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies whether the certificate should be present or absent.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_content: {
      type: 'Optional[String]',
      desc: 'The base64 encoded content of the CER file you want to import.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_store: {
      type: 'String',
      desc: 'The Windows Certificate Store Name to import the certificate to.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_location: {
      type: "Enum['LocalMachine', 'localmachine', 'CurrentUser', 'currentuser']",
      desc: 'The Windows Certificate Store Location to import the certificate to.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'Optional[String]',
      desc: 'The path to the CER file you want to import.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_friendlyname: {
      type: 'Optional[String]',
      desc: 'The friendly name of the certificate to set in the Windows Certificate Store.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
