require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_certreq',
  dscmeta_resource_friendly_name: 'CertReq',
  dscmeta_resource_name: 'DSC_CertReq',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'CertificateDsc',
  dscmeta_module_version: '6.0.0',
  docs: 'The DSC CertReq resource type.
         Automatically generated from version 6.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_keyusage: {
      type: 'Optional[String]',
      desc: 'The Keyusage is a restriction method that determines what a certificate can be used for.',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_subject: {
      type: 'String',
      desc: 'Provide the text string to use as the subject of the certificate.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_keylength: {
      type: "Optional[Enum['192', '224', '256', '384', '521', '1024', '2048', '4096', '8192']]",
      desc: 'The bit length of the encryption key to be used. Defaults to 2048.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_oid: {
      type: 'Optional[String]',
      desc: 'The Object Identifier that is used to name the object.',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_keytype: {
      type: "Optional[Enum['RSA', 'rsa', 'ECDH', 'ecdh']]",
      desc: 'Specifies if the key type should be RSA or ECDH, defaults to RSA.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_carootname: {
      type: 'Optional[String]',
      desc: 'The name of the certificate authority, by default this will be in format domain-servername-ca. Leave empty to automatically locate.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_catype: {
      type: 'Optional[String]',
      desc: 'The type of CA in use, Standalone/Enterprise.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'The `PSCredential` object containing the credentials that will be used to access the template in the Certificate Authority.',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_cepurl: {
      type: 'Optional[String]',
      desc: 'The URL to the Certification Enrollment Policy Service.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_caserverfqdn: {
      type: 'Optional[String]',
      desc: 'The FQDN of the Active Directory Certificate Authority on the local area network. Leave empty to automatically locate.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_cesurl: {
      type: 'Optional[String]',
      desc: 'The URL to the Certification Enrollment Service.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usemachinecontext: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not the flag -adminforcemachine will be used when requesting certificates. Necessary for certain templates like e.g. DomainControllerAuthentication',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_subjectaltname: {
      type: 'Optional[String]',
      desc: 'The subject alternative name used to create the certificate.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_autorenew: {
      type: 'Optional[Boolean]',
      desc: 'Determines if the resource will also renew a certificate within 7 days of expiration.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_exportable: {
      type: 'Optional[Boolean]',
      desc: 'The option to allow the certificate to be exportable, by default it will be true.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_friendlyname: {
      type: 'String',
      desc: 'Specifies a friendly name for the certificate.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_providername: {
      type: 'Optional[String]',
      desc: 'The selection of provider for the type of encryption to be used.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_requesttype: {
      type: "Optional[Enum['CMC', 'cmc', 'PKCS10', 'pkcs10']]",
      desc: 'Specifies if the request type should be CMC or PKCS10, deafults to CMC.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatetemplate: {
      type: 'Optional[String]',
      desc: 'The template used for the definition of the certificate.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
